pub enum Expr {
Alias(Alias),
Column(ColumnExpr),
Literal(Literal),
Binary(BinaryExpr),
Cast(Cast),
AggregateFunction(AggregateFunction),
}Variants
Alias(Alias)
An expression with a specific name.
Column(ColumnExpr)
A named reference to a qualified filed in a schema.
Literal(Literal)
A constant value.
Binary(BinaryExpr)
A binary expression such as “age > 21”
Cast(Cast)
Casts the expression to a given type and will return a runtime error if the expression cannot be cast. This expression is guaranteed to have a fixed type.
AggregateFunction(AggregateFunction)
Represents the call of an aggregate built-in function with arguments.