pub struct Alias {
pub expr: Box<Expr>,
pub name: String,
}Fields
expr: Box<Expr>name: StringTrait Implementations
Sourceimpl ExprTrait for Alias
impl ExprTrait for Alias
Sourcefn data_type(&self, input_schema: &Schema) -> QuillSQLResult<DataType>
fn data_type(&self, input_schema: &Schema) -> QuillSQLResult<DataType>
Get the data type of this expression, given the schema of the input
Sourcefn nullable(&self, input_schema: &Schema) -> QuillSQLResult<bool>
fn nullable(&self, input_schema: &Schema) -> QuillSQLResult<bool>
Determine whether this expression is nullable, given the schema of the input
Sourcefn evaluate(&self, tuple: &Tuple) -> QuillSQLResult<ScalarValue>
fn evaluate(&self, tuple: &Tuple) -> QuillSQLResult<ScalarValue>
Evaluate an expression against a Tuple
impl Eq for Alias
impl StructuralPartialEq for Alias