pub struct Literal {
pub value: ScalarValue,
}Fields
value: ScalarValueTrait Implementations
Sourceimpl ExprTrait for Literal
impl ExprTrait for Literal
Sourcefn data_type(&self, _input_schema: &Schema) -> QuillSQLResult<DataType>
fn data_type(&self, _input_schema: &Schema) -> QuillSQLResult<DataType>
Get the data type of this expression, given the schema of the input
Sourcefn nullable(&self, _input_schema: &Schema) -> QuillSQLResult<bool>
fn nullable(&self, _input_schema: &Schema) -> QuillSQLResult<bool>
Determine whether this expression is nullable, given the schema of the input
Sourcefn evaluate(&self, _tuple: &Tuple) -> QuillSQLResult<ScalarValue>
fn evaluate(&self, _tuple: &Tuple) -> QuillSQLResult<ScalarValue>
Evaluate an expression against a Tuple
impl Eq for Literal
impl StructuralPartialEq for Literal