pub struct EliminateLimit;Trait Implementations
Sourceimpl LogicalOptimizerRule for EliminateLimit
impl LogicalOptimizerRule for EliminateLimit
Sourcefn try_optimize(
&self,
plan: &LogicalPlan,
) -> QuillSQLResult<Option<LogicalPlan>>
fn try_optimize( &self, plan: &LogicalPlan, ) -> QuillSQLResult<Option<LogicalPlan>>
Try and rewrite
plan to an optimized form, returning None if the plan cannot be
optimized by this rule.Sourcefn apply_order(&self) -> Option<ApplyOrder>
fn apply_order(&self) -> Option<ApplyOrder>
How should the rule be applied by the optimizer Read more