LockManager

Struct LockManager 

pub struct LockManager { /* private fields */ }

Implementations

Source

impl LockManager

pub fn new() -> Self

Create a new lock manager.

pub fn default_instance() -> Self

Create a lock manager using default configuration.

pub fn lock_table( &self, txn: &Transaction, mode: LockMode, table_ref: TableReference, ) -> bool

Acquire a table level lock for the given transaction.

pub fn unlock_table(&self, txn: &Transaction, table_ref: TableReference) -> bool

Release a table level lock held by the transaction.

pub fn lock_row( &self, txn: &Transaction, mode: LockMode, table_ref: TableReference, rid: RecordId, ) -> bool

Acquire a row level lock for the given transaction.

pub fn unlock_row( &self, txn: &Transaction, table_ref: TableReference, rid: RecordId, _force: bool, ) -> bool

Release a row level lock held by the transaction.

pub fn unlock_table_raw( &self, txn_id: TransactionId, table_ref: TableReference, ) -> bool

pub fn unlock_row_raw( &self, txn_id: TransactionId, table_ref: TableReference, rid: RecordId, ) -> bool

pub fn unlock_all(&self)

Force release of all locks (used during shutdown/testing).

pub fn debug_snapshot(&self) -> LockDebugSnapshot